package com.sun.org.apache.xpath.internal.axes;

import com.sun.org.apache.xpath.internal.objects.XObject;
import com.sun.org.apache.xpath.internal.XPathContext;
import javax.xml.transform.TransformerException;
import com.sun.org.apache.xpath.internal.patterns.NodeTest;
import java.util.Vector;

public class UnionChildIterator extends ChildTestIterator
{
    static final long serialVersionUID = 3500298482193003495L;
    private PredicatedNodeTest[] m_nodeTests;
    
    public UnionChildIterator() {
        super(null);
        this.m_nodeTests = null;
    }
    
    public void addNodeTest(PredicatedNodeTest test) {
        if (null == this.m_nodeTests) {
            (this.m_nodeTests = new PredicatedNodeTest[1])[0] = test;
        }
        else {
            PredicatedNodeTest[] tests = this.m_nodeTests;
            int len = this.m_nodeTests.length;
            System.arraycopy(tests, 0, this.m_nodeTests = new PredicatedNodeTest[len + 1], 0, len);
            this.m_nodeTests[len] = test;
        }
        test.exprSetParent(this);
    }
    
    @Override
    public void fixupVariables(Vector vars, int globalsSize) {
        super.fixupVariables(vars, globalsSize);
        if (this.m_nodeTests != null) {
            for (int i = 0; i < this.m_nodeTests.length; ++i) {
                this.m_nodeTests[i].fixupVariables(vars, globalsSize);
            }
        }
    }
    
    @Override
    public short acceptNode(int n) {
        XPathContext xctxt = this.getXPathContext();
        try {
            xctxt.pushCurrentNode(n);
            for (int i = 0; i < this.m_nodeTests.length; ++i) {
                PredicatedNodeTest pnt = this.m_nodeTests[i];
                XObject score = pnt.execute(xctxt, n);
                if (score != NodeTest.SCORE_NONE) {
                    if (pnt.getPredicateCount() > 0) {
                        if (pnt.executePredicates(n, xctxt)) {
                            return 1;
                        }
                    }
                    else {
                        return 1;
                    }
                }
            }
        }
        catch (TransformerException se) {
            throw new RuntimeException(se.getMessage());
        }
        finally {
            xctxt.popCurrentNode();
        }
        return 3;
    }
}
